@@ -2,6 +2,7 @@ package Weather::Com::DateTime;
 
 use 5.006;
 use strict;
+no warnings;
 
 #use warnings;
 use Carp;
@@ -9,7 +10,7 @@ use Data::Dumper;
 use Time::Format;
 use Time::Local;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.4 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.7 $ =~ /(\d+)/g;
 
 our %months = (
 	'Jan' => 0,
@@ -145,7 +146,6 @@ sub formatted {
 	
 	# Time::Format always returns localtime of the server the
 	# script runs on. We have to eliminate this.
-	#my $fakeepoc = (gmtime($self->{EPOC}));
 	my $localepoc = $self->{EPOC} + ( $self->{ZONE} * 3600 );
 	return $time{ $format, $localepoc };    
 }
@@ -382,7 +382,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2005 by Thomas Schnuecker
+Copyright (C) 2004-2007 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
