@@ -5,7 +5,11 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
+#--------------------------------------------------------------------
+# Define some globals
+#--------------------------------------------------------------------
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)/g;
+my %LH = ();  # our language handles
 
 #------------------------------------------------------------------------
 # Constructor
@@ -28,10 +32,9 @@ sub new {
 	# creating the SUPER instance
 	$self->{ARGS} = \%parameters;
 	if ( $parameters{lang} ) {
-		$self->{LH} = Weather::Com::L10N->get_handle( $parameters{lang} )
-		  or croak("Language?");
+		$self->{LANGUAGE} = $parameters{lang};
 	} else {
-		$self->{LH} = Weather::Com::L10N->get_handle('en_US');
+		$self->{LANGUAGE} = 'en_US';
 	}
 
 	
@@ -46,4 +49,22 @@ sub update {
 	return 1;
 }
 
+#------------------------------------------------------------------------
+# Get a language handle
+#------------------------------------------------------------------------
+sub get_language_handle {
+	my $self = shift;
+	my $lang = shift || $self->{LANGUAGE};
+	
+	# check if we already have an open handle
+	unless (defined($LH{$lang})) {
+		$LH{$lang} = Weather::Com::L10N->get_handle($lang) 
+			or croak ("Language?");
+	}
+	
+	# return language handle
+	return $LH{$lang};
+}
+
+
 1;
